@@ -1,6 +1,6 @@
-#' Load .fam file
+#' Load `.fam` file
 #'
-#' @param path The path to a .fam file.
+#' @param path The path to a `.fam` file.
 #' @param fallbackModel The name of a mutation model; passed on to
 #'   [pedFamilias::readFam()].
 #' @param withParams A logical indicating if the Familias parameters should be
@@ -16,6 +16,7 @@
 #' @export
 loadFamFile = function(path, fallbackModel = "equal", withParams = FALSE) {
   if (getOption("KLINK.debug")) print("loadFamFile")
+
   x0 = pedFamilias::readFam(path, useDVI = NA, verbose = FALSE,
                             prefixAdded = ":missing:", includeParams = TRUE,
                             fallbackModel = fallbackModel, simplify1 = FALSE)
@@ -46,35 +47,48 @@ loadFamFile = function(path, fallbackModel = "equal", withParams = FALSE) {
       stop2("Unexpected content detected in the Familias file.")
   })
 
+  x1 = x[[1]]
+
+  nMark = nMarkers(x1)
+  if(nMark == 0)
+    stop2("No markers are included in the Familias file.")
+
+  typed = typedMembers(x1)
+  if(length(typed) == 0)
+    warning("No typed individuals found in the Familias file.", call. = FALSE)
+
   if(length(x) == 1) {
     warning("Only one pedigree found. Adding unrelated hypothesis", call. = FALSE)
-    un = singletons(typedMembers(x[[1]]))
-    un = transferMarkers(from = x[[1]], to = un)
+
+    if(length(typed) == 0)
+      stop2("The second pedigree is empty.")
+
+    un = singletons(typed)
+    un = transferMarkers(from = x1, to = un)
     x = c(x, list(un))
   }
 
   if(length(x) > 2) {
-    warning("This familias file contains more than two pedigrees; only the first two are used", call. = FALSE)
+    warning("This familias file contains more than two pedigrees; only the first two are used",
+            call. = FALSE)
     x = x[1:2]
   }
 
-  if(!specialLumpability(x)) {
-    alwLumpable = vapply(1:nMarkers(x[[1]]), FUN.VALUE = FALSE, function(i)
-      is.null(mut <- mutmod(x[[1]], i)) || pedmut::alwaysLumpable(mut))
-    if(!all(alwLumpable)) {
-      x = lapply(x, function(ped)
-        setMutmod(ped, markers = !alwLumpable, model = fallbackModel, update = TRUE))
-      msg = sprintf("Pedigree prohibits lumping of complex mutation models; changed these to '%s'",
-                    fallbackModel)
-      warning(msg, call. = FALSE)
-    }
-  }
-
   if(is.null(names(x)))
     names(x) = c("Ped 1", "Ped 2")
   else if(any(msnm <- names(x) == ""))
     names(x)[msnm] = paste("Ped", which(msnm))
 
+  # Check Lumpability
+  lumpable = checkLumpability(x[[1]]) & checkLumpability(x[[2]])
+  if(!all(lumpable)) {
+    msg = sprintf("Pedigree prohibits lumping for %d markers; changed models '%s'",
+                  sum(!lumpable), fallbackModel)
+    warning(msg, call. = FALSE)
+    x = lapply(x, function(ped)
+      setMutmod(ped, which(!lumpable), model = fallbackModel, update = TRUE))
+  }
+
   if(withParams)
     list(peds = x, params = params)
   else
@@ -83,15 +97,52 @@ loadFamFile = function(path, fallbackModel = "equal", withParams = FALSE) {
 
 
 removeEmpty = function(x) {
-  if (getOption("KLINK.debug")) print("removeEmpty")
+  if (getOption("KLINK.debug")) print("remove empty comps and/or markers")
   if(is.null(x))
     return(NULL)
+
   for(pedname in names(x)) {
     ped = x[[pedname]]
     empty = vapply(ped, function(comp) !any(unlist(comp$MARKERS)), FALSE)
     if(all(empty))
-      stop2(sprintf("Pedigree '%s' has no typed members", pedname))
-    x[[pedname]] = ped[!empty]
+      warning(sprintf("Pedigree '%s' has no typed members", pedname))
+    else
+      x[[pedname]] = ped[!empty]
   }
   x
 }
+
+checkLumpability = function(x) {
+
+  nMark = nMarkers(x)
+
+  # Regular lumpability
+  alwLumpable = vapply(seq_len(nMark), function(i)
+    pedmut::alwaysLumpable(mutmod(x, i)), FUN.VALUE = logical(1))
+
+  if(all(alwLumpable))
+    return(alwLumpable)
+
+  # For special lumping, check U-signature
+  untyped = untypedMembers(x)
+  usign = pedprobr:::uSignature(x, untyped = untyped)
+  if(usign[1] > 1 || (usign[3] + usign[4]) > 0)
+    return(rep(FALSE, nMark))
+
+  # If all markers have the same untyped, ok!
+  res = rep(TRUE, nMark)
+  gg = getGenotypes(x)
+  if(all(colSums(gg == "-/-") == length(untyped)))
+    return(res)
+
+  # Otherwise, check each marker
+  for(i in seq_len(nMark)) {
+    unt = names(which(gg[, i] == "-/-"))
+    us = if(setequal(unt, untyped)) usign else pedprobr:::uSignature(x, untyped = unt)
+    if(us[1] > 1 || (us[3] + us[4]) > 0)
+      res[i] = FALSE
+    else if(us[2] > 3 && nAlleles(x, i) > 20)
+      res[i] = FALSE
+  }
+  res
+}
