@@ -12,44 +12,44 @@
 #' @export
 markerSummary = function(pedigrees, replaceNames = FALSE) {
   ped1 = pedigrees[[1]]
-  # ped2 = pedigrees[[2]] # not used?
 
   # Check if special (founder-type) lumping applies to all markers
-  specLump = specialLumpability(pedigrees)
+  # specLump = specialLumpability(pedigrees)
 
   # Genotypes
-  geno = t.default(pedtools::getGenotypes(ped1, ids = typedMembers(ped1)))
-  if(replaceNames)
+  typed = typedMembers(ped1)
+  geno = t.default(pedtools::getGenotypes(ped1, ids = typed))
+  if(replaceNames && length(typed) > 0)
     colnames(geno) = paste0("Person", 1:ncol(geno))
 
+
   # List of lists: Marker attributes
   locAttrs = pedtools::getLocusAttributes(ped1)
 
   reslist = lapply(locAttrs, function(a) {
+    gg = geno[a$name, , drop = FALSE]
     mut = a$mutmod
-    pars = pedmut::getParams(mut, c("model", "rate", "range", "rate2"), format = 3)
-    colnames(pars) = c("Model", "Rate", "Range", "Rate2")
+    pars = pedmut::getParams(mut, c("model", "rate", "rate2", "range"), format = 3)
+    colnames(pars) = c("Model", "Rate", "Rate2", "Range")
+    pars$Model = capit(pars$Model)
 
-    if(is.null(mut)) {
-      lumptxt = stattxt = "-"
-    }
-    else {
-      lumptxt = if(pedmut::alwaysLumpable(mut)) "Always" else if (specLump) "Yes" else "No"
+    lumptxt = stattxt = NA_character_
+    if(!is.null(mut)) {
+      lumptxt = if(pedmut::alwaysLumpable(mut)) "Always" else "No"  #if (specLump) "Special" else
       stattxt = if(pedmut::isStationary(mut)) "Yes" else "No"
     }
     cbind.data.frame(Marker = a$name,
+                     gg, Typed = sum(gg != "-/-"),
                      Alleles = length(a$alleles),
                      PIC = PIC(a$afreq),
                      MinFreq = sprintf("%.2g", min(a$afreq)),
-                     geno[a$name, , drop = FALSE],
-                     pars, Stationary = stattxt, Lumpable = lumptxt)
+                     pars,
+                     Stat = stattxt,
+                     Lump = lumptxt)
   })
 
   res = do.call(rbind, reslist)
 
-  if(any(grepl("/", res$Rate, fixed = TRUE)))
-    colnames(res)[colnames(res) == "Rate"] = "Rate (f/m)"
-
   rownames(res) = NULL
   res
 }
@@ -61,5 +61,9 @@ PIC = function(afr) 1 - sum(afr^2) - sum(afr^2)^2 + sum(afr^4)
 lp2vec = function(markers, linkedPairs) {
   pairvec = rep(seq_along(linkedPairs), each = 2)
   names(pairvec) = unlist(linkedPairs)
-  as.integer(pairvec[markers])
+  idx = matchMarkernames(markers, names(pairvec))
+  vec = as.integer(pairvec[idx])
+  singles = which(tabulate(vec) == 1)
+  vec[vec %in% singles] = NA
+  vec
 }
